@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 2007 Free Software Foundation, Inc.
+ * Copyright 2007, 2008 Free Software Foundation, Inc.
  * Written by Paolo Bonzini.
  *
  * This file is part of GNU Smalltalk.
@@ -117,7 +117,7 @@ struct tool tools[] = {
   {
     "gst-doc", "scripts/GenDoc.st",
     "-h|--help --version -p|--package: -f|--file: -I|--image-file: \
-        -o|--output: --kernel-directory:",
+        -n|--namespace: -o|--output: --kernel-directory:",
     NULL
   },
   { NULL, NULL, NULL, NULL }
