@@ -113,14 +113,15 @@ typedef struct gst_cfunc_descriptor
                                    addr */ 
   OOP cFunctionName;            /* Name of C function in mapping table */
   OOP returnType;               /* Smalltalk return type */
-  OOP tagOOP;
-  OOP argTypes[1];              /* variable length.  */
+  OOP numFixedArgs;             /* number of real arguments passed from
+                                   smalltalk (excluding "self" parameters
+                                   which are synthetically added when 
+                                   calling the C function).  */
+  OOP argTypes[1];              /* variable length, really numFixedArgs
+                                   long */
 }
  *gst_cfunc_descriptor;
 
-/* Returns the size of an object passed to a C routine with type TYPE.  */
-extern int _gst_c_type_size (int type);
-
 /* Invokes a C routine.  Arguments passed from Smalltalk are stored starting
    from ARGS, and the object to which the message that called-out was
    sent is RECEIVER.  CFUNCOOP is the C function descriptor used
@@ -145,14 +146,13 @@ extern void _gst_define_cfunc (const char *funcName, PTR funcAddr)
 extern void _gst_init_cfuncs (void) 
   ATTRIBUTE_HIDDEN;
 
-/* Makes a CFunctionDescriptor (the actual class is in CLASSOOP) for a
-   callout method.  Returns a gst_cfunc_descriptor object which holds onto
-   the descriptor.  This descriptor is subsequently used when the called
-   out function FUNCNAMEOOP (a Smalltalk String) is invoked. RETURNOOP
-   is a Symbol or CType which indicates the return type and ARGSOOP is
-   a Smalltalk Array containing the argument types (as Symbols).  */
-extern OOP _gst_make_descriptor (OOP classOOP,
-				 OOP funcNameOOP,
+/* Makes a C based descriptor for a callout method.  Returns a
+   gst_cfunc_descriptor object which holds onto the descriptor.  This
+   descriptor is subsequently used when the called out function
+   FUNCNAMEOOP (a Smalltalk String) is invoked. RETURNOOP is a Symbol
+   or CType which indicates the return type and ARGSOOP is a Smalltalk
+   Array containing the argument types (as Symbols).  */
+extern OOP _gst_make_descriptor (OOP funcNameOOP,
 				 OOP returnTypeOOP,
 				 OOP argsOOP) 
   ATTRIBUTE_HIDDEN;
