@@ -676,9 +676,10 @@ optimize_basic_block (gst_uchar * from,
 	  break;
 
         case PUSH_TEMPORARY_VARIABLE:
-        case PUSH_LIT_VARIABLE:
         case PUSH_RECEIVER_VARIABLE:
-	  /* Leave only the store in store/pop/push sequences.  */
+	  /* Leave only the store in store/pop/push sequences.  Don't do this
+	     for STORE_LIT_VARIABLE, as it fails if #value: is sent and,
+	     for example, self is returned.  */
 	  if (opt >= from + 4
 	      && (opt == from + 4 || opt[-6] != EXT_BYTE)
 	      && opt[-4] == bp[0] + (STORE_TEMPORARY_VARIABLE - PUSH_TEMPORARY_VARIABLE)
@@ -936,15 +937,15 @@ _gst_compute_stack_positions (gst_uchar * bp,
 	    }
 
 	    SEND_ARITH {
-	      balance -= _gst_builtin_selectors[n]->numArgs;
+	      balance -= _gst_builtin_selectors[n].numArgs;
 	    }
 
 	    SEND_IMMEDIATE {
-	      balance -= super + _gst_builtin_selectors[n]->numArgs;
+	      balance -= super + _gst_builtin_selectors[n].numArgs;
 	    }
 
             SEND_SPECIAL {
-	      balance -= _gst_builtin_selectors[n + 16]->numArgs;
+	      balance -= _gst_builtin_selectors[n + 16].numArgs;
 	    }
 
             INVALID {
@@ -1130,8 +1131,8 @@ typedef struct partially_constructed_array {
 #define CHECK_LIT_VARIABLE(store, n) \
   CHECK_LITERAL (n); \
   if (IS_INT (literals[(n)]) || \
-      !is_a_kind_of (OOP_CLASS (literals[(n)]), _gst_association_class)) \
-    return ("Association expected"); \
+      !is_a_kind_of (OOP_CLASS (literals[(n)]), _gst_lookup_key_class)) \
+    return ("LookupKey expected"); \
   else if (store \
 	   && untrusted \
 	   && !IS_OOP_UNTRUSTED (literals[(n)])) \
@@ -1392,10 +1393,10 @@ _gst_verify_method (OOP methodOOP, int *num_outer_temps, int depth)
 	    }
 
 	    SEND_ARITH {
-	      if (!_gst_builtin_selectors[n])
+	      if (!_gst_builtin_selectors[n].symbol)
 		return ("invalid immediate send");
 
-	      balance -= _gst_builtin_selectors[n]->numArgs;
+	      balance -= _gst_builtin_selectors[n].numArgs;
 
 	      /* Sends touch the new stack top, so they require an extra slot.  */
 	      if (curr_sp + balance < 1)
@@ -1403,10 +1404,10 @@ _gst_verify_method (OOP methodOOP, int *num_outer_temps, int depth)
 	    }
 
             SEND_SPECIAL {
-	      if (!_gst_builtin_selectors[n + 16])
+	      if (!_gst_builtin_selectors[n + 16].symbol)
 		return ("invalid immediate send");
 
-	      balance -= _gst_builtin_selectors[n + 16]->numArgs;
+	      balance -= _gst_builtin_selectors[n + 16].numArgs;
 
 	      /* Sends touch the new stack top, so they require an extra slot.  */
 	      if (curr_sp + balance < 1)
@@ -1414,10 +1415,10 @@ _gst_verify_method (OOP methodOOP, int *num_outer_temps, int depth)
 	    }
 
             SEND_IMMEDIATE {
-	      if (!_gst_builtin_selectors[n])
+	      if (!_gst_builtin_selectors[n].symbol)
 		return ("invalid immediate send");
 
-	      balance -= super + _gst_builtin_selectors[n]->numArgs;
+	      balance -= super + _gst_builtin_selectors[n].numArgs;
 
 	      /* Sends touch the new stack top, so they require an extra slot.  */
 	      if (curr_sp + balance < 1)
@@ -1726,11 +1727,11 @@ _gst_verify_method (OOP methodOOP, int *num_outer_temps, int depth)
 	    }
 
 	    SEND_ARITH {
-	      sp -= _gst_builtin_selectors[n]->numArgs;
+	      sp -= _gst_builtin_selectors[n].numArgs;
 	      sp[-1] = FROM_INT (VARYING);
 	    }
 	    SEND_SPECIAL {
-	      sp -= _gst_builtin_selectors[n + 16]->numArgs;
+	      sp -= _gst_builtin_selectors[n + 16].numArgs;
 	      sp[-1] = FROM_INT (VARYING);
 	    }
 
@@ -1769,7 +1770,7 @@ _gst_verify_method (OOP methodOOP, int *num_outer_temps, int depth)
 		    return (_gst_debug (), "Invalid send to super");
 
 		  last_used_literal = NULL;
-	          sp -= super + _gst_builtin_selectors[n]->numArgs;
+	          sp -= super + _gst_builtin_selectors[n].numArgs;
 	          if (super && sp[-1] != FROM_INT (SELF))
 		    return ("Invalid send to super");
 
