@@ -1,3 +1,4 @@
+#line 1 "../../../snprintfv/snprintfv/stream.in"
 /*  -*- Mode: C -*-  */
 
 /* stream.h --- customizable stream routines
@@ -17,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  * As a special exception to the GNU General Public License, if you
  * distribute this file as part of a program that also links with and
@@ -30,17 +31,6 @@
 #ifndef STREAM_H
 #define STREAM_H 1
 
-#ifndef PARAMS
-#  if __STDC__
-#    ifndef NOPROTOS
-#      define PARAMS(args)	args
-#    endif
-#  endif
-#  ifndef PARAMS
-#    define PARAMS(args)	()
-#  endif
-#endif
-
 #define STREAM_READABLE		(1 << 0)
 #define STREAM_WRITABLE		(1 << 1)
 
@@ -79,7 +69,7 @@ typedef struct stream STREAM;
  * stream, cast to an int if it was written successfully, or
  * else %EOF, if the write failed.
  **/
-typedef int (*StreamPut) PARAMS ((int ch, STREAM * stream));
+typedef int (*StreamPut) (int ch, STREAM * stream);
 
 /**
  * StreamGet:
@@ -92,7 +82,7 @@ typedef int (*StreamPut) PARAMS ((int ch, STREAM * stream));
  * stream, cast to an int if it was read successfully, or
  * else %EOF, if the read failed.
  **/
-typedef int (*StreamGet) PARAMS ((STREAM * stream));
+typedef int (*StreamGet) (STREAM * stream);
 
 
 /**
@@ -109,7 +99,8 @@ typedef int (*StreamGet) PARAMS ((STREAM * stream));
  * Return value:
  * The address of the newly allocated and initialised stream is returned.
  **/
-extern STREAM * stream_new PARAMS((snv_pointer dets, unsigned long limit, StreamGet get_func, StreamPut put_func));
+extern STREAM * stream_new (snv_pointer dets, unsigned long limit, StreamGet get_func, StreamPut put_func);
+
 
 /**
  * stream_delete:  destructor 
@@ -120,7 +111,8 @@ extern STREAM * stream_new PARAMS((snv_pointer dets, unsigned long limit, Stream
  * The %dets supplied by the user when the stream was created are
  * returned for handling by the calling function.
  **/
-extern snv_pointer stream_delete PARAMS((STREAM *stream));
+extern snv_pointer stream_delete (STREAM *stream);
+
 
 /**
  * stream_details:   
@@ -134,7 +126,8 @@ extern snv_pointer stream_delete PARAMS((STREAM *stream));
  * This function returns the stream details associated with @stream
  * when it was originally created.
  **/
-extern snv_pointer stream_details PARAMS((STREAM *stream));
+extern snv_pointer stream_details (STREAM *stream);
+
 
 /**
  * stream_put:   
@@ -148,10 +141,30 @@ extern snv_pointer stream_details PARAMS((STREAM *stream));
  * If @stream is full, return 1.  Otherwise, if any other error occurs,
  * that error code is returned unchanged.  This is of course dependant
  * on what the handler function uses to indicate an error.  If the stream
- * is not full and the stream's writing function suceeds, 1 (the number of
+ * is not full and the stream's writing function succeeds, 1 (the number of
  * characters emitted!) is returned.
  **/
-extern int stream_put PARAMS((int ch, STREAM *stream));
+extern int stream_put (int ch, STREAM *stream);
+
+
+/**
+ * stream_puts:   
+ * @s: A string to be placed in @stream.
+ * @stream: The stream to be written to.
+ *
+ * This function will @ch in @stream if that stream's output limit will
+ * not be exceeded.
+ *
+ * Return value:
+ * If any other error occurs, that error code is returned unchanged.
+ * This is of course dependant on what the handler function uses to
+ * indicate an error.  If the stream becomes full, the remaining
+ * characters are not printed.  If the stream's writing function
+ * always succeeds, the number of characters emitted or skipped is
+ * returned.
+ **/
+extern int stream_puts (char *s, STREAM *stream);
+
 
 /**
  * stream_get:   
@@ -164,8 +177,10 @@ extern int stream_put PARAMS((int ch, STREAM *stream));
  * Under normal circumstances the value if the character read (cast to
  * an int) is returned.
  **/
-extern int stream_get PARAMS((STREAM *stream));
+extern int stream_get (STREAM *stream);
 
+
+#line 88 "../../../snprintfv/snprintfv/stream.in"
 #ifdef __cplusplus
 #if 0
 /* This brace is so that emacs can still indent properly: */
